#include "SimpleAnalysis/AnalysisClass.h"

DefineAnalysis(EwkFullHad2018)
void EwkFullHad2018::Init()
{
  addRegions({"Preselection","Preselection0L4Q","Preselection0L2B2Q","Preselection1L4Q","Preselection1L2B2Q","Preselection1Y4Q","Preselection1Y2B2Q"});
  addRegions({"SR4QWW","SR4QWZ","SR4QZZ","SR4QVV","SR2B2QWZ","SR2B2QWh","SR2B2QZZ","SR2B2QZh","SR2B2QVZ","SR2B2QVh"});
  addRegions({"CR4Q","CR2B2Q"});
  addRegions({"VR1L4Q1T1F","VR1L4Q2T","VR1L2B2Q1T1F","VR1L2B2Q2T","VR1Y4Q1T1F","VR1Y4Q2T","VR1Y2B2Q1T1F","VR1Y2B2Q2T"});
  //
  addHistogram("cutflow",30,0,30);
}


void EwkFullHad2018::ProcessEvent(AnalysisEvent *event)
{
   //====================================================================================================
   // get baseline objects
   // cfr. STconfig: https://gitlab.cern.ch/atlas-phys-susy-wg/Electroweak/fullyhadronic/SusySkimEWKHad/-/blob/master/data/SUSYTools/SUSYTools_SusySkimEWKHad_Rel21.conf
   auto baselineElectrons  = event->getElectrons(7., 2.47, ELooseBLLH | EZ05mm);
   auto baselineMuons      = event->getMuons(6, 2.7, MuMedium | MuZ05mm | MuNotCosmic | MuQoPSignificance);
   auto baselineJets       = event->getJets(30., 4.5);
   auto baselinePhotons    = event->getPhotons(50, 2.37, PhotonTight);
   auto baselineTrackjets  = event->getTrackJets(5, 2.8);
   auto metVec             = event->getMET();
   double met              = metVec.Et();
   auto trackjets          = filterObjects(baselineTrackjets, 20, 2.8);
   auto trackmetVec             = event->getTrackMET();
   double trackmet              = trackmetVec.Et();
   auto fatjets   = event->getFatJets(200, 2.0);


   //====================================================================================================
   // overlap removal
   auto radiusCalcLepton = [] (const AnalysisObject& lepton, const AnalysisObject&) { return std::min(0.4, 0.04 + 10./lepton.Pt()); };
   auto radiusCalcTrackj = [] (const AnalysisObject& trackj, const AnalysisObject&) { return std::max(0.02, std::min( 0.4, 30./trackj.Pt())); };
   // 1. e-mu: shared ID track
   baselineElectrons = overlapRemoval(baselineElectrons, baselineMuons, 0.01);
   // 2. gamma-e/mu: deltaR < 0.4
   baselinePhotons   = overlapRemoval(baselinePhotons, baselineElectrons, 0.4);
   baselinePhotons   = overlapRemoval(baselinePhotons, baselineMuons, 0.4);
   // 3a. j-e: deltaR < 0.2
   baselineJets      = overlapRemoval(baselineJets, baselineElectrons, 0.2);
   // 3b. j-gamma: deltaR < 0.2
   baselineJets      = overlapRemoval(baselineJets, baselinePhotons, 0.2);
   // 3c. j-mu: deltaR < 0.2 but only LessThanThreeTrack
   baselineJets      = overlapMuPFJRemoval(baselineJets, baselineMuons, 0.4, LessThan3Tracks); // for PFlow
   //baselineJets      = overlapRemoval(baselineJets, baselineMuons, 0.4, LessThan3Tracks);
   // 4. e/mu-j: (62.5:dR=0.2, 27.8: dR=0.4) variable radius: no leptons removed below/above 28/60
   baselineElectrons = overlapRemoval(baselineElectrons, baselineJets, radiusCalcLepton);
   baselineMuons     = overlapRemoval(baselineMuons, baselineJets, radiusCalcLepton);
   baselinePhotons   = overlapRemoval(baselinePhotons, baselineJets, 0.4);
   // 5. track j-e/mu : variable radius
   trackjets         = overlapRemoval(trackjets, baselineElectrons, radiusCalcTrackj);
   // 6. large-R jet removal : dR(l/gamma, large-R jet)
   fatjets           = overlapRemoval(fatjets, baselineElectrons, 1.0);
   fatjets           = overlapRemoval(fatjets, baselineMuons, 1.0);
   fatjets           = overlapRemoval(fatjets, baselinePhotons, 1.0);


   //====================================================================================================
   auto baselineleptons = baselineElectrons + baselineMuons;
   int nbaselineleptons = baselineleptons.size();

   TLorentzVector tlv(0.,0.,0.,0.);
   for ( auto particles : baselineElectrons){
	TLorentzVector tmptlv;
	tmptlv.SetPxPyPzE(particles.Px(), particles.Py(), particles.Pz(), particles.E());
	tlv += tmptlv;
   }
   for ( auto particles : baselineMuons){
	TLorentzVector tmptlv;
	tmptlv.SetPxPyPzE(particles.Px(), particles.Py(), particles.Pz(), particles.E());
	tlv += tmptlv;
   }
   for ( auto particles : baselineJets){
	TLorentzVector tmptlv;
	tmptlv.SetPxPyPzE(particles.Px(), particles.Py(), particles.Pz(), particles.E());
        tlv += tmptlv;
   }
   for ( auto particles : baselinePhotons){
	TLorentzVector tmptlv;
	tmptlv.SetPxPyPzE(particles.Px(), particles.Py(), particles.Pz(), particles.E());
        tlv += tmptlv;
   }
   TLorentzVector tlv2(0.,0.,0.,0.);
   tlv2.SetPxPyPzE(-tlv.Px(), -tlv.Py(), -tlv.Pz(), tlv.E());

   //====================================================================================================
   // signal objects
   //auto electrons = filterObjects(baselineElectrons, 7, 2.47, ETightLH | ED0Sigma5 | EZ05mm | EIsoFCTight | EIsoFCHighPtCaloOnly);
   auto electrons = filterObjects(baselineElectrons, 7, 2.47, ETightLH | ED0Sigma5 | EZ05mm | EIsoFCTight);
   auto muons     = filterObjects(baselineMuons, 6, 2.7, MuD0Sigma3 | MuZ05mm | MuIsoFixedCutLoose);
   auto photons   = filterObjects(baselinePhotons, 150, 2.37, PhotonIsoFixedCutTight);
   auto taus      = event->getTaus(20, 2.5, TauMedium);
   auto jets      = filterObjects(baselineJets, 30, 2.8, JVT50Jet);
   auto bjets     = filterObjects(jets, 30., 2.8, BTag85MV2c10);
   auto btrackjets= filterObjects(trackjets, 20, 2.8, BTag85MV2c10);
   auto leptons   = electrons + muons;

   //====================================================================================================
   int nleptons   = leptons.size();
   int nelectrons = electrons.size();
   int nmuons     = muons.size();
   int nphotons   = photons.size();
   int nbaselinejets      = baselineJets.size();
   int njets      = jets.size();
   int nbjets     = bjets.size();
   int ntrackbjets= btrackjets.size();
   int nfatjets   = fatjets.size();
   // TO DO : trackjets DR cut cleaning

   // pT order the objects
   sortObjectsByPt(leptons);
   sortObjectsByPt(jets);
   sortObjectsByPt(fatjets);

   int cutflowcounter = 0;
   fill("cutflow", cutflowcounter++);

   //if ( nfatjets < 2) return;

   // add some variables
   double minDPhi_met_allJets30 = 999.;
   for ( const auto& tmpjets : jets){
	minDPhi_met_allJets30 = std::min(acos(cos(metVec.Phi() - tmpjets.Phi())), minDPhi_met_allJets30);
   }
   int fatJet1NGATrkB85 = 0;
   int fatJet2NGATrkB85 = 0;
   if ( nfatjets > 0) {
   for ( const auto& tmpjets : btrackjets){
	if(nfatjets > 0){
		if(hypot(tmpjets.Eta()-fatjets.at(0).Eta(),acos(cos(tmpjets.Phi()-fatjets.at(0).Phi()))) < 1.0) fatJet1NGATrkB85 += 1;
		if(nfatjets > 1){
			if(hypot(tmpjets.Eta()-fatjets.at(1).Eta(),acos(cos(tmpjets.Phi()-fatjets.at(1).Phi()))) < 1.0) fatJet2NGATrkB85 += 1;
		}
	}
   }
   }


   //====================================================================================================

   TLorentzVector fatjet1_2btagged;
   TLorentzVector fatjet2_2btagged;
   if(nfatjets > 0) fatjet1_2btagged.SetPtEtaPhiM(fatjets.at(0).Pt(),fatjets.at(0).Eta(),fatjets.at(0).Phi(),fatjets.at(0).M());
   if(nfatjets > 1) fatjet2_2btagged.SetPtEtaPhiM(fatjets.at(1).Pt(),fatjets.at(1).Eta(),fatjets.at(1).Phi(),fatjets.at(1).M());
   int n1add = 0;
   int n2add = 0;
   if ( nfatjets > 0) {
   for(const auto& muon : event->getMuons(0, 2.7, MuZ05mm | MuNotCosmic | MuQoPSignificance)){
	if(n1add >= fatJet1NGATrkB85) break;
	if(hypot(fatjet1_2btagged.Eta()-muon.Eta(),acos(cos(fatjet1_2btagged.Phi()-muon.Phi()))) < 1.0){
		TLorentzVector tmpmu;
		tmpmu.SetPtEtaPhiM(muon.Pt(),muon.Eta(),muon.Phi(),muon.M());
		fatjet1_2btagged += tmpmu;
		n1add += 1;
	}
   }
   }
   if ( nfatjets > 1) {
   for(const auto& muon : event->getMuons(0, 2.7, MuZ05mm | MuNotCosmic | MuQoPSignificance)){
	if(n2add >= fatJet2NGATrkB85) break;
	if(hypot(fatjet2_2btagged.Eta()-muon.Eta(),acos(cos(fatjet2_2btagged.Phi()-muon.Phi()))) < 1.0){
		TLorentzVector tmpmu;
		tmpmu.SetPtEtaPhiM(muon.Pt(),muon.Eta(),muon.Phi(),muon.M());
		fatjet2_2btagged += tmpmu;
		n2add += 1;
	}
   }
   }
   
   float mt2_BB_100 = 0.;
   if ( nfatjets > 1) mt2_BB_100 = calcAMT2(fatjets.at(0),fatjets.at(1), event->getMET(), 100., 100.) -100.;
   TLorentzVector TLVW;
   TLorentzVector leadinglepton(0,0,0,0);
   double L1_minDPhi_met_allJets30 = 999.;
   if(nleptons >= 1){
	leadinglepton.SetPtEtaPhiM(leptons.at(0).Pt(), leptons.at(0).Eta(), leptons.at(0).Phi(), leptons.at(0).M());
	TLVW.SetPtEtaPhiM(leptons.at(0).Pt(), leptons.at(0).Eta(), leptons.at(0).Phi(), leptons.at(0).M());
	TLorentzVector tmpMis;
	tmpMis.SetPtEtaPhiM(metVec.Et(), 0, metVec.Phi(), 0);
	//tmpMis.SetPtEtaPhiM(tlv2.Et(), 0, tlv2.Phi(), 0);
	TLVW += tmpMis;
   	for ( const auto& tmpjets : jets){
		L1_minDPhi_met_allJets30 = std::min(acos(cos(TLVW.Phi() - tmpjets.Phi())), L1_minDPhi_met_allJets30);
   	}
    }
   TLorentzVector fatJet1, fatJet2;
   if ( nfatjets > 0) fatJet1.SetPtEtaPhiM(fatjets.at(0).Pt(),fatjets.at(0).Eta(),fatjets.at(0).Phi(),fatjets.at(0).M());
   if ( nfatjets > 1) fatJet2.SetPtEtaPhiM(fatjets.at(1).Pt(),fatjets.at(1).Eta(),fatjets.at(1).Phi(),fatjets.at(1).M());
   float L1_mt2_BB_100 = calcAMT2(fatJet1,fatJet2,TLVW,100.,100.)-100.;
   TLorentzVector leadingphoton(0,0,0,0);

   float Y1_mt2_BB_100 = 0.;
   double Y1_minDPhi_met_allJets30 = 999.;
   if (nphotons == 1){
   	leadingphoton.SetPtEtaPhiM(photons.at(0).Pt(), photons.at(0).Eta(), photons.at(0).Phi(), photons.at(0).M());
	for ( const auto& tmpjets : jets){
		Y1_minDPhi_met_allJets30= std::min(acos(cos(leadingphoton.Phi() - tmpjets.Phi())),Y1_minDPhi_met_allJets30);
	}
   	Y1_mt2_BB_100 = calcAMT2(fatJet1,fatJet2,leadingphoton,100.,100.)-100.;
   }

   // for 0L temporary 
   bool pass0L_Precut = false;
   if (nbaselineleptons == 0){
	//not require trigger
	//not require lepton for combination
	//not require trackjet DR cut
	//not require bad tile
	//not require non-collision veto
	pass0L_Precut = met > 200. && nfatjets >= 2 && minDPhi_met_allJets30 > 1.;
   }

   // for 1L temporary 
   bool pass1L_Precut = false;
   if (nleptons == 1){
	//not require trigger
	//not require lepton for combination
	//not require trackjet DR cut
	//not require bad tile
	pass1L_Precut = TLVW.Pt() > 200. && nfatjets >= 2 && L1_minDPhi_met_allJets30 > 1. && leptons.at(0).Pt() > 30. && met > 50.;
   }

   // for 1Y temporary 
   bool pass1Y_Precut = false;
   if (nphotons == 1){
	//not require trigger
	//not require lepton for combination
	//not require trackjet DR cut
	//not require bad tile
	pass1Y_Precut = photons.at(0).Pt() > 200. && nfatjets >= 2 && Y1_minDPhi_met_allJets30 > 1. && met < 200. && nbaselineleptons == 0;
   }
   //if(!pass0L_Precut && !pass1L_Precut && !pass1Y_Precut) return;
	std::cout << "0L : " << pass0L_Precut << ", 1L : " << pass1L_Precut << ", 1Y : " << pass1Y_Precut << std::endl;


   //====================================================================================================
   //do assignment by closest to mZ
   double mZ  = 91.1876;
   double mll = -999.;
   double mdiff = 1e6;
   int nSFOS = 0;
   int iZ1(-1), iZ2(-1), iW(-1);

   //====================================================================================================

   //====================================================================================================
   // at this point everything should be assigned!

   //====================================================================================================

   //====================================================================================================
   // require the Zpeak [75,105]

   //====================================================================================================

   //====================================================================================================
   if(minDPhi_met_allJets30 > 1.0 && nbaselineleptons==0 && met > 200. && nfatjets >= 2){
	accept("Preselection0L");
	if(ntrackbjets-fatJet1NGATrkB85-fatJet2NGATrkB85 == 0){
		if(fatJet1NGATrkB85+fatJet2NGATrkB85 <= 1){
			accept("Preselection0L4Q");
			if(met > 300. && met+fatjets.at(0).Pt()+fatjets.at(1).Pt() > 1300.){
				if(fatjets.at(0).pass(WTag) && fatjets.at(1).pass(WTag)) accept("SR4QWW");
				if((fatjets.at(0).pass(WTag) && fatjets.at(1).pass(ZTag)) || (fatjets.at(0).pass(ZTag) && fatjets.at(1).pass(WTag))) accept("SR4QWZ");
				if(fatjets.at(0).pass(ZTag) && fatjets.at(1).pass(ZTag)) accept("SR4QZZ");
				if((fatjets.at(0).pass(WTag) || fatjets.at(0).pass(ZTag)) && (fatjets.at(1).pass(WTag) || fatjets.at(1).pass(ZTag))) accept("SR4QVV");
			}
		}

		if((fatJet1NGATrkB85==2 && fatJet2NGATrkB85 <= 1) || (fatJet1NGATrkB85 <= 1 && fatJet2NGATrkB85 == 2)){
			accept("Preselection0L2B2Q");
			if(mt2_BB_100 > 250. && met+fatjets.at(0).Pt()+fatjets.at(1).Pt() > 1000.){
				bool fatJet1Zbb = fatJet1NGATrkB85==2 && fatjet1_2btagged.M() > 70. && fatjet1_2btagged.M() < 100.;
				bool fatJet1hbb = fatJet1NGATrkB85==2 && fatjet1_2btagged.M() > 100. && fatjet1_2btagged.M() < 135.;
				bool fatJet2Zbb = fatJet2NGATrkB85==2 && fatjet2_2btagged.M() > 70. && fatjet2_2btagged.M() < 100.;
				bool fatJet2hbb = fatJet2NGATrkB85==2 && fatjet2_2btagged.M() > 100. && fatjet2_2btagged.M() < 135.;
				if((fatjets.at(0).pass(WTag) && fatJet2Zbb) || (fatJet1Zbb && fatjets.at(1).pass(WTag))) accept("SR2B2QWZ");
				if((fatjets.at(0).pass(WTag) && fatJet2hbb) || (fatJet1hbb && fatjets.at(1).pass(WTag))) accept("SR2B2QWh");
				if((fatjets.at(0).pass(ZTag) && fatJet2Zbb) || (fatJet1Zbb && fatjets.at(1).pass(ZTag))) accept("SR2B2QZZ");
				if((fatjets.at(0).pass(ZTag) && fatJet2hbb) || (fatJet1hbb && fatjets.at(1).pass(ZTag))) accept("SR2B2QZh");
				if(((fatjets.at(0).pass(WTag) || fatjets.at(0).pass(ZTag)) && fatJet2Zbb) || (fatJet1Zbb && (fatjets.at(1).pass(WTag) || fatjets.at(1).pass(ZTag)))) accept("SR2B2QVZ");
				if(((fatjets.at(0).pass(WTag) || fatjets.at(0).pass(ZTag)) && fatJet2hbb) || (fatJet1hbb && (fatjets.at(1).pass(WTag) || fatjets.at(1).pass(ZTag)))) accept("SR2B2QVh");
			}
		}
	}
   }


   ntupVar("met_Et", met);
   ntupVar("met_Phi", metVec.Phi());
   ntupVar("reco_met", tlv2.Pt());
   ntupVar("reco_met_Phi", tlv2.Phi());
   ntupVar("L1_WPt", TLVW.Pt());
   ntupVar("L1_WPhi", TLVW.Phi());
   ntupVar("photon1Pt", leadingphoton.Pt());
   ntupVar("photon1Phi", leadingphoton.Phi());
   ntupVar("photon1Etai", leadingphoton.Eta());
   ntupVar("lep1Pt", leadinglepton.Pt());
   ntupVar("lep1Phi", leadinglepton.Phi());
   ntupVar("lep1Eta", leadinglepton.Eta());
   ntupVar("passPrecut", pass0L_Precut || pass1L_Precut || pass1Y_Precut);
   //
   ntupVar("njets", njets);
   ntupVar("nJet30", nbaselinejets);
   ntupVar("nFatJets", nfatjets);
   ntupVar("nbjets", nbjets);
   ntupVar("nLep_base", nbaselineleptons);
   ntupVar("nLep_signal", nleptons);
   ntupVar("nTrackBJet20",ntrackbjets);
   if(nfatjets >= 1){
   	ntupVar("fatJet1Pt", fatjets.at(0).Pt());
   	ntupVar("fatJet1M", fatjets.at(0).M());
   	ntupVar("fatJet1Eta", fatjets.at(0).Eta());
   	ntupVar("fatJet1Phi", fatjets.at(0).Phi());
   	ntupVar("fatJet1IsW", fatjets.at(0).pass(WTag));
   	ntupVar("fatJet1IsZ", fatjets.at(0).pass(ZTag));
   	ntupVar("fatJet1IsV", fatjets.at(0).pass(WTag) || fatjets.at(0).pass(ZTag));
        ntupVar("fatJet1WTagSF", fatjets.at(0).getWTagSF());
        ntupVar("fatJet1ZTagSF", fatjets.at(0).getZTagSF());
        ntupVar("fatJet1ZbbTagSF", fatjets.at(0).getZbbTagSF());
        ntupVar("fatJet1hbbTagSF", fatjets.at(0).gethbbTagSF());
	bool isWMass = fatjets.at(0).Pt() < 3000. ? (fatjets.at(0).M() > sqrt(pow((-1.17489e4)/fatjets.at(0).Pt()+(6.34351e1),2)+pow((-2.39185e-2)*fatjets.at(0).Pt()+(6.92862e1),2)) && fatjets.at(0).M() < sqrt(pow((1.59377e4)/fatjets.at(0).Pt()+(-2.90870e1),2)+pow((4.92512e-3)*fatjets.at(0).Pt()+(8.94082e1),2))) : (fatjets.at(0).M() > 59.570001 && fatjets.at(0).M() < 106.86177);
	bool isZMass = fatjets.at(0).Pt() < 3000. ? (fatjets.at(0).M() > sqrt(pow((-1.44222e4)/fatjets.at(0).Pt()+(7.25877e1),2)+pow((-2.75481e-2)*fatjets.at(0).Pt()+(7.87757e1),2)) && fatjets.at(0).M() < sqrt(pow((6.22596e3)/fatjets.at(0).Pt()+(8.27925),2)+pow((7.51060e-3)*fatjets.at(0).Pt()+(9.76893e1),2))) : (fatjets.at(0).M() > 67.890612 && fatjets.at(0).M() < 120.66619);
	ntupVar("fatJet1IsWMass",isWMass);
	ntupVar("fatJet1IsZMass",isZMass);
   }
   if(nfatjets >= 2){
   	ntupVar("fatJet2M", fatjets.at(1).M());
   	ntupVar("fatJet2Pt", fatjets.at(1).Pt());
   	ntupVar("fatJet2Eta", fatjets.at(1).Eta());
   	ntupVar("fatJet2Phi", fatjets.at(1).Phi());
   	ntupVar("fatJet2IsW", fatjets.at(1).pass(WTag));
   	ntupVar("fatJet2IsZ", fatjets.at(1).pass(ZTag));
   	ntupVar("fatJet2IsV", fatjets.at(1).pass(WTag) || fatjets.at(1).pass(ZTag));
        ntupVar("fatJet2WTagSF", fatjets.at(1).getWTagSF());
        ntupVar("fatJet2ZTagSF", fatjets.at(1).getZTagSF());
        ntupVar("fatJet2ZbbTagSF", fatjets.at(1).getZbbTagSF());
        ntupVar("fatJet2hbbTagSF", fatjets.at(1).gethbbTagSF());
	bool isWMass = fatjets.at(1).Pt() < 3000. ? (fatjets.at(1).M() > sqrt(pow((-1.17489e4)/fatjets.at(1).Pt()+(6.34351e1),2)+pow((-2.39185e-2)*fatjets.at(1).Pt()+(6.92862e1),2)) && fatjets.at(1).M() < sqrt(pow((1.59377e4)/fatjets.at(1).Pt()+(-2.90870e1),2)+pow((4.92512e-3)*fatjets.at(1).Pt()+(8.94082e1),2))) : (fatjets.at(1).M() > 59.570001 && fatjets.at(1).M() < 106.86177);
	bool isZMass = fatjets.at(1).Pt() < 3000. ? (fatjets.at(1).M() > sqrt(pow((-1.44222e4)/fatjets.at(1).Pt()+(7.25877e1),2)+pow((-2.75481e-2)*fatjets.at(1).Pt()+(7.87757e1),2)) && fatjets.at(1).M() < sqrt(pow((6.22596e3)/fatjets.at(1).Pt()+(8.27925),2)+pow((7.51060e-3)*fatjets.at(1).Pt()+(9.76893e1),2))) : (fatjets.at(1).M() > 67.890612 && fatjets.at(1).M() < 120.66619);
	ntupVar("fatJet2IsWMass",isWMass);
	ntupVar("fatJet2IsZMass",isZMass);
   }
   ntupVar("fatJet1NGATrkB85", fatJet1NGATrkB85);
   ntupVar("fatJet2NGATrkB85", fatJet2NGATrkB85);
   ntupVar("fatJet1M_oneMuCor", fatjet1_2btagged.M());
   ntupVar("fatJet2M_oneMuCor", fatjet2_2btagged.M());
   ntupVar("minDPhi_met_allJets30", minDPhi_met_allJets30);
   ntupVar("L1_minDPhi_met_allJets30", L1_minDPhi_met_allJets30);
   ntupVar("Y1_minDPhi_met_allJets30", Y1_minDPhi_met_allJets30);
   ntupVar("mt2_BB_100", mt2_BB_100);
   ntupVar("L1_mt2_BB_100", L1_mt2_BB_100);
   ntupVar("Y1_mt2_BB_100", Y1_mt2_BB_100);
   //
   //
   // ISR
   //
   //ntupVar("susyProcess", event->getSUSYChannel());
   ntupVar("mcDSID", event->getMCNumber());
   ntupVar("mcWeights", event->getMCWeights());
   int runNum = event->getRunNumber();
   ntupVar("mcRunNumber", runNum);
   int year = 2015;
   if (runNum == 284500 ) year = 2016;
   else if(runNum == 300000) year = 2017;
   else if(runNum == 310000) year = 2018;
   ntupVar("year",year);
   double periodWeight = 1.;
   if(year == 2016) periodWeight = 0.260;
   else if(year == 2017) periodWeight = 0.319;
   else if(year == 2018) periodWeight = 0.421;
   ntupVar("periodWeight",periodWeight);

  int isZZ = 0;
  int isZh = 0;
  int ishh = 0;
  if(event->get_boson_pdg1() == 23 && event->get_boson_pdg2() == 23) isZZ = 1;
  else if(event->get_boson_pdg1() == 25 && event->get_boson_pdg2() == 25) ishh = 1;
  else if(!(event->get_boson_pdg1() == 23 || event->get_boson_pdg1() == 25) || !(event->get_boson_pdg2() == 23 || event->get_boson_pdg2() == 25)) std::cout << "Oh! My God!" << std::endl;
  else isZh = 1;
  ntupVar("isZZ",isZZ);
  ntupVar("isZh",isZh);
  ntupVar("ishh",ishh);

   return;
}
